@@ -75,8 +75,8 @@ def apply_product_policies(for_real, customer):
     return customer, data
 
 
-def update_customer_cdr(customer):
+def update_customer_cdr(last_date, customer):
     """Mise à jour des CDRs d'un client dans la base REDIS"""
-    customer.get_cdr_from_aiguillier()
+    customer.get_cdr_from_aiguillier(last_date=last_date)
 
 # EOF
