@@ -145,6 +145,11 @@ class Customer(object):
                             'period': period
                         }
                         )
+                    LOGS.logger.info("Defuper un client {}-{}-{}".format(
+                        self.name,
+                        policy_name,
+                        period
+                        ))
                     url = core.database_url(**FUPDB_CREDENTIALS)
                     with records.Database(url) as db:
                         sql = (
@@ -175,12 +180,15 @@ class Customer(object):
                         'code': '204',
                         'message': 'produit non fupé'
                         }
-
-            LOGS.logger.info("Defuper un client {}-{}-{}".format(
-                self.name,
-                policy_name,
-                period
-                ))
+            url = core.database_url(**FUPDB_CREDENTIALS)
+            with records.Database(url) as db:
+                sql = "DELETE FROM customer WHERE name=:name"
+                db.query(sql, name=self.name)
+                sql = "DELETE FROM cdr WHERE customer=:name"
+                db.query(sql, name=self.name)
+                sql = "DELETE FROM fup WHERE customer=:name"
+                db.query(sql, name=self.name)
+            LOGS.logger.info("Suppression du client {}".format(self.name))
         return result
 
     def get_cdr_from_aiguillier(self, last_date):
